==> nextcloud-13.0.1.tgz: nextcloud/apps/theming/l10n/nb.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laster forhåndsvisning…",
    "Saved" : "Lagret",
    "Admin" : "Admin",
    "a safe home for all your data" : "et trygt hjem for alle dine data",
    "Name cannot be empty" : "Navn kan ikke være tom",
    "The given name is too long" : "Navnet er for langt",
    "The given web address is too long" : "Nettadressen er for lang",
    "The given slogan is too long" : "Slagordet er for langt",
    "The given color is invalid" : "Fargen er ugyldig",
    "There is no error, the file uploaded with success" : "Det er ingen feil, filen ble lastet opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Filen er større enn grensen satt i upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen du prøvde å laste opp er større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet",
    "No file was uploaded" : "Ingen filer ble lastet opp",
    "Missing a temporary folder" : "Mangler midlertidig mappe",
    "Failed to write file to disk." : "Klarte ikke å skrive til disk.",
    "A PHP extension stopped the file upload." : "En PHP-utvidelse stoppet filopplastingen.",
    "No file uploaded" : "Ingen fil lastet opp",
    "Unsupported image type" : "Filtypen støttes ikke",
    "You are already using a custom theme" : "Du bruker allerede en egendefinert drakt",
    "Theming" : "Draktvalg",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Draktvalg gjør det enkelt å tilpasse utseende og følelsen av din installasjon og støttede klienter. Dette vil bli synlig for alle brukere.",
    "Name" : "Navn",
    "Reset to default" : "Tilbakestill til forvalg",
    "Web address" : "Nettadresse",
    "Web address https://…" : "Nettadresse https://…",
    "Slogan" : "Slagord",
    "Color" : "Farge",
    "Logo" : "Logo",
    "Upload new logo" : "Last opp ny logo",
    "Login image" : "Innloggingsbilde",
    "Upload new login background" : "Last opp ny innloggingsbakgrunn",
    "Remove background image" : "Fjern bakgrunnsbilde",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installer PHP-utvidelsen Imagemagick med støtte for SVG-bilder for å opprette favikoner automatisk basert på opplastet logo og farge.",
    "reset to default" : "tilbakestill til forvalg",
    "The uploaded file was only partially uploaded" : "Filen ble bare delvis lastet opp"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/theming/l10n/nb.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laster forhåndsvisning…",
    "Saved" : "Lagret",
    "Admin" : "Admin",
    "a safe home for all your data" : "et trygt hjem for alle dine data",
    "Name cannot be empty" : "Navn kan ikke være tom",
    "The given name is too long" : "Navnet er for langt",
    "The given web address is too long" : "Nettadressen er for lang",
    "The given legal notice address is too long" : "Den oppgitte juridiske varslingsadressen er for lang",
    "The given privacy policy address is too long" : "Personvernerklæring-addressen er for lang",
    "The given slogan is too long" : "Slagordet er for langt",
    "The given color is invalid" : "Fargen er ugyldig",
    "The file was uploaded" : "Filen ble lastet opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Filen er større enn grensen satt i upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen du prøvde å laste opp er større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet",
    "The file was only partially uploaded" : "Filen ble kun delvis nedlastet",
    "No file was uploaded" : "Ingen filer ble lastet opp",
    "Missing a temporary folder" : "Mangler midlertidig mappe",
    "Could not write file to disk" : "Kunne ikke skrive fil til disk",
    "A PHP extension stopped the file upload" : "A PHP-utvidelse stoppet filopplastingen",
    "No file uploaded" : "Ingen fil lastet opp",
    "Unsupported image type" : "Filtypen støttes ikke",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du bruker et tilpasset tema. Innstillinger i program for tilpasning av tema kan bli overskrevet av disse.",
    "Legal notice" : "Juridisk varsel",
    "Privacy policy" : "Personvern",
    "Theming" : "Draktvalg",
    "Adjust the Nextcloud theme" : "Tilpass Nextcloud tema/drakt",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Draktvalg gjør det enkelt å tilpasse utseende og følelsen av din installasjon og støttede klienter. Dette vil bli synlig for alle brukere.",
    "Name" : "Navn",
    "Reset to default" : "Tilbakestill til standard",
    "Web link" : "Nettside lenke",
    "https://…" : "https://…",
    "Slogan" : "Slagord",
    "Color" : "Farge",
    "Logo" : "Logo",
    "Upload new logo" : "Last opp ny logo",
    "Login image" : "Innloggingsbilde",
    "Upload new login background" : "Last opp ny innloggingsbakgrunn",
    "Remove background image" : "Fjern bakgrunnsbilde",
    "Advanced options" : "Avanserte innstillinger",
    "Legal notice link" : "Juridisk varslingslenke",
    "Privacy policy link" : "Personvernerklæring",
    "Header logo" : "Header logo",
    "Upload new header logo" : "Last opp ny header logo",
    "Favicon" : "Favoritt ikon",
    "Upload new favicon" : "Last opp nytt ikon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installer PHP-utvidelsen Imagemagick med støtte for SVG-bilder for å opprette favikoner automatisk basert på opplastet logo og farge.",
    "There is no error, the file uploaded with success" : "Det er ingen feil, filen ble lastet opp",
    "The uploaded file was only partially uploaded" : "Filen ble bare delvis lastet opp",
    "Failed to write file to disk." : "Skriving til disk mislyktes",
    "A PHP extension stopped the file upload." : "En PHP-utvidelse stoppet filopplastingen.",
    "You are already using a custom theme" : "Du bruker allerede en egendefinert drakt",
    "Web address https://…" : "Nettadresse https://…"
},
"nplurals=2; plural=(n != 1);");
